//=========================================================
// PSoC5LP Project
//=========================================================
// File Name : spi.c
// Function  : SPI Control
//---------------------------------------------------------
// Rev.01 2012.09.01 Munetomo Maruyama
//---------------------------------------------------------
// Copyright (C) 2012-2013 Munetomo Maruyama
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You can copy, modify and distribute this code.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include "spi.h"

//======================
// Initialize SPI
//======================
void Init_SPI(void)
{
    SPIM_1_Start();
}

//===============================
// SPI Transfer and Receive Data
//===============================
uint32 SPI_TxRxData(uint32 txdata)
{
    uint32 rxdata;

    // Tx : Wait for Buffer Empty
    while((SPIM_1_ReadTxStatus() & SPIM_1_STS_TX_FIFO_EMPTY) == 0);
    // Tx : Send a byte
    SPIM_1_WriteTxData((uint16)txdata);
    // Tx : Wait for end of Transfer
    while((SPIM_1_ReadTxStatus() & SPIM_1_STS_SPI_DONE) == 0);

    // Rx : Wait for Buffer Not Empty
    while((SPIM_1_ReadRxStatus() & SPIM_1_STS_RX_FIFO_NOT_EMPTY) == 0);
    // Rx : Recieve a byte    
    rxdata = (uint32)SPIM_1_ReadRxData();

    return rxdata;
}

//======================
// SPI Transfer Data
//======================
void SPI_TxData(uint32 txdata)
{
    SPI_TxRxData(txdata);
}

//======================
// SPI Receive Data
//======================
uint32 SPI_RxData(void)
{
    uint32 rxdata;

    rxdata = SPI_TxRxData(0x1ff); // 9bits
    return rxdata;
}

//=========================================================
// End of Program
//=========================================================
