/*******************************************************************************
* File Name: ANT.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "ANT.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 ANT__PORT == 15 && ((ANT__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: ANT_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void ANT_Write(uint8 value) 
{
    uint8 staticBits = (ANT_DR & (uint8)(~ANT_MASK));
    ANT_DR = staticBits | ((uint8)(value << ANT_SHIFT) & ANT_MASK);
}


/*******************************************************************************
* Function Name: ANT_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void ANT_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(ANT_0, mode);
}


/*******************************************************************************
* Function Name: ANT_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ANT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ANT_Read(void) 
{
    return (ANT_PS & ANT_MASK) >> ANT_SHIFT;
}


/*******************************************************************************
* Function Name: ANT_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ANT_ReadDataReg(void) 
{
    return (ANT_DR & ANT_MASK) >> ANT_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ANT_INTSTAT) 

    /*******************************************************************************
    * Function Name: ANT_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ANT_ClearInterrupt(void) 
    {
        return (ANT_INTSTAT & ANT_MASK) >> ANT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
